@@ -36,6 +36,8 @@ module Hasql.Decoders
     numeric,
     char,
     text,
+    varchar,
+    bpchar,
     bytea,
     date,
     timestamp,
