@@ -25,6 +25,8 @@ module Hasql.Encoders
     numeric,
     char,
     text,
+    varchar,
+    bpchar,
     bytea,
     date,
     timestamp,
